View source: R/catpredi.survival.R
| catpredi.survival | R Documentation |
Returns an object with the optimal cut points to categorise a continuous predictor variable in a Cox proportional hazards regression model
catpredi.survival(
formula,
cat.var,
cat.points = 1,
data,
method = c("addfor", "genetic", "backaddfor"),
conc.index = c("cindex", "cpe"),
range = NULL,
correct.index = FALSE,
control = controlcatpredi.survival(),
...
)
formula |
An object of class |
cat.var |
Name of the continuous variable to categorise. |
cat.points |
Number of cut points to look for. |
data |
Data frame containing all needed variables. |
method |
The algorithm selected to search for the optimal cut points.
|
conc.index |
The concordance probability estimator selected for maximisation purposes. "cindex" if the c-index concordance probability is choosen and "cpe" otherwise. The c-index and CPE are estimated using the rms and CPE packages, respectively. |
range |
The range of the continuous variable in which to look for the cut
points. By default |
correct.index |
A logical value. If TRUE the bias corrected concordance probability is estimated. |
control |
Output of the |
... |
Further arguments for passing on to the function |
Returns an object of class "catpredi.survival" with the following components:
The matched call.
The algorithm selected in the call.
an object of class formula giving the model to
be fitted in addition to the continuous covariate is aimed to categorise.
name of the continuous variable to categorise.
the data frame with the variables used in the call.
The logical value used in the call.
a list with the estimated cut points, concordance probability and bias corrected concordance probability.
the control parameters used in the call.
When the c-index concordance probability is choosen, a list with the following components is obtained for each of the methods used in the call:
Estimated optimal cut points.
Estimated c-index.
Estimated bias corrected c-index.
When the CPE concordance probability is choosen, a list with the following components is obtained for each of the methods used in the call:
Estimated optimal cut points.
Estimated CPE.
Estimated bias corrected CPE.
Irantzu Barrio and Maria Xose Rodriguez-Alvarez
I Barrio, M.X Rodriguez-Alvarez, L Meira-Machado, C Esteban and I Arostegui (2017). Comparison of two discrimination indexes in the categorisation of continuous predictors in time-to-event studies. SORT, 41:73-92
M Gonen and G Heller (2005). Concordance probability and discriminatory power in proportional hazards regression. Biometrika, 92:965-970.
F Harrell (2001). Regression modeling strategies: with applications to linear models, logistic and ordinal regression, and survival analysis. Springer.
controlcatpredi.survival,
comp.cutpoints.survival,
plot.catpredi.survival,
catpredi
library(CatPredi)
library(survival)
set.seed(123)
#Simulate data
n = 500
tauc = 1
X <- rnorm(n=n, mean=0, sd=2)
SurvT <- exp(2*X + rweibull(n = n, shape=1, scale = 1)) + rnorm(n, mean=0, sd=0.25)
# Censoring time
CensTime <- runif(n=n, min=0, max=tauc)
# Status
SurvS <- as.numeric(SurvT <= CensTime)
# Data frame
dat <- data.frame(X = X, SurvT = pmin(SurvT, CensTime), SurvS = SurvS)
# Select optimal cut points using the AddFor algorithm
res <- catpredi.survival (formula= Surv(SurvT,SurvS)~1, cat.var="X", cat.points = 2,
data = dat, method = "addfor", conc.index = "cindex", range = NULL,
correct.index = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.