View source: R/controlcatpredi.R
| controlcatpredi | R Documentation |
Function used to set several parameters to control the selection of the optimal cut points in a logistic regression model
controlcatpredi(
min.p.cat = 1,
grid = 100,
B = 50,
eps = 0.001,
b.method = c("ncoutcome", "coutcome"),
print.gen = 0
)
min.p.cat |
Set the minimun number of individuals in each category |
grid |
Grid size for the AddFor and BackAddFor algorithms |
B |
Number of bootstrap replicates for the AUC bias correction procedure |
eps |
An argument for the BackAddFor algorithm, indicating whether the improvement between iterations is considered significant |
b.method |
Allows to specify whether the bootstrap resampling should be done considering or not the outcome variable. The option "ncoutcome" indicates that the data is resampled without taking into account the response variable, while "coutcome" indicates that the data is resampled in regard to the response variable |
print.gen |
Corresponds to the argument print.level of the |
A list with components for each of the possible arguments.
Irantzu Barrio, Maria Xose Rodriguez-Alvarez, Inmaculada Arostegui, Javier Roca-Pardinas and Xabier Amutxastegi.
Mebane Jr, W. R., & Sekhon, J. S. (2011). Genetic optimization using derivatives: the rgenoud package for R. Journal of Statistical Software 4211, 1-26.
catpredi
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.