plot.catpredi.survival: Plot the optimal cut points.

View source: R/plot.catpredi.survival.R

plot.catpredi.survivalR Documentation

Plot the optimal cut points.

Description

Plots the functional form of the predictor variable we want to categorise. Additionally, the optimal cut points obtained with the catpredi.survival() function are drawn on the graph.

Usage

## S3 method for class 'catpredi.survival'
plot(x, ...)

Arguments

x

An object of type catpredi.survival.

...

Additional arguments to be passed on to other functions. Not yet implemented.

Value

This function returns the plot of the relationship between the predictor variable and the outcome.

Author(s)

Irantzu Barrio and Maria Xose Rodriguez-Alvarez.

References

I Barrio, M.X Rodriguez-Alvarez, L Meira-Machado, C Esteban and I Arostegui (2017). Comparison of two discrimination indexes in the categorisation of continuous predictors in time-to-event studies. SORT, 41:73-92

See Also

catpredi.survival

Examples

library(CatPredi)
library(survival)
set.seed(123)
#Simulate data
n = 500
tauc = 1
X <- rnorm(n=n, mean=0, sd=2)
SurvT <- exp(2*X + rweibull(n = n, shape=1, scale = 1))   + rnorm(n, mean=0, sd=0.25)
# Censoring time
CensTime <- runif(n=n, min=0, max=tauc)
# Status
SurvS <- as.numeric(SurvT <= CensTime)
# Data frame
dat <- data.frame(X = X, SurvT = pmin(SurvT, CensTime), SurvS = SurvS)

# Select optimal cut points using the AddFor algorithm
res <- catpredi.survival (formula= Surv(SurvT,SurvS)~1, cat.var="X", cat.points = 2,
                          data = dat, method = "addfor", conc.index = "cindex", range = NULL,
                          correct.index = FALSE)
# Plot
plot(res)


CatPredi documentation built on May 8, 2026, 9:07 a.m.