View source: R/comp.cutpoints.R
| comp.cutpoints | R Documentation |
Compares two objects of class "catpredi".
comp.cutpoints(obj1, obj2, V = 100)
obj1 |
An object inheriting from class |
obj2 |
An object inheriting from class |
V |
Number of bootstrap resamples. By default V=100 |
This function returns an object of class "comp.cutpoints" with the following components:
the difference of the bias corrected AUCs for the two categorical variables.
bootstrap based confidence interval for the bias corrected AUC difference.
Irantzu Barrio, Maria Xose Rodriguez-Alvarez and Inmaculada Arostegui.
I Barrio, I Arostegui, M.X Rodriguez-Alvarez and J.M Quintana (2017). A new approach to categorising continuous variables in prediction models: proposal and validation. Statistical Methods in Medical Research, 26(6), 2586-2602.
catpredi
library(CatPredi)
set.seed(127)
#Simulate data
n = 100
#Predictor variable
xh <- rnorm(n, mean = 0, sd = 1)
xd <- rnorm(n, mean = 1.5, sd = 1)
x <- c(xh, xd)
#Response
y <- c(rep(0,n), rep(1,n))
# Data frame
df <- data.frame(y = y, x = x)
# Select 2 optimal cut points using the AddFor algorithm. Correct the AUC
res.backaddfor.k2 <- catpredi(formula = y ~ 1, cat.var = "x", cat.points = 2,
data = df, method = "backaddfor", range=NULL, correct.AUC=TRUE,
control=controlcatpredi(grid=100))
# Select 3 optimal cut points using the AddFor algorithm. Correct the AUC
res.backaddfor.k3 <- catpredi(formula = y ~ 1, cat.var = "x", cat.points = 3,
data = df, method = "backaddfor", range=NULL, correct.AUC=TRUE,
control=controlcatpredi(grid=100))
# Select optimal number of cut points
comp <- comp.cutpoints(res.backaddfor.k2, res.backaddfor.k3, V = 100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.