View source: R/comp.cutpoints.survival.R
| comp.cutpoints.survival | R Documentation |
Compares two objects of class "catpredi.survival"
comp.cutpoints.survival(obj1, obj2, V = 100)
obj1 |
An object inheriting from class |
obj2 |
An object inheriting from class |
V |
Number of bootstrap resamples. By default V=100 |
This function returns an object of class "comp.cutpoints.survival" with the following components:
the difference of the bias corrected concordance probability for the two categorical variables.
bootstrap based confidence interval for the bias corrected concordance probability difference.
Irantzu Barrio and Maria Xose Rodriguez-Alvarez.
I Barrio, M.X Rodriguez-Alvarez, L Meira-Machado, C Esteban and I Arostegui (2017). Comparison of two discrimination indexes in the categorisation of continuous predictors in time-to-event studies. SORT, 41:73-92
catpredi.survival
library(CatPredi)
library(survival)
set.seed(123)
#Simulate data
n = 300
tauc = 1
X <- rnorm(n=n, mean=0, sd=2)
SurvT <- exp(2*X + rweibull(n = n, shape=1, scale = 1)) + rnorm(n, mean=0, sd=0.25)
# Censoring time
CensTime <- runif(n=n, min=0, max=tauc)
# Status
SurvS <- as.numeric(SurvT <= CensTime)
# Data frame
dat <- data.frame(X = X, SurvT = pmin(SurvT, CensTime), SurvS = SurvS)
# Select 2 optimal cut points using the AddFor algorithm. Correct the c-index
res.k2 <- catpredi.survival (formula= Surv(SurvT,SurvS)~1, cat.var="X", cat.points = 2,
data = dat, method = "addfor", conc.index = "cindex",
range = NULL, correct.index = TRUE)
# Select 3 optimal cut points using the AddFor algorithm. Correct the c-index
res.k3 <- catpredi.survival (formula= Surv(SurvT,SurvS)~1, cat.var="X", cat.points = 3,
data = dat, method = "addfor", conc.index = "cindex",
range = NULL, correct.index = TRUE)
# Select optimal number of cut points
comp <- comp.cutpoints.survival(res.k2, res.k3, V = 100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.